
# Find the process ID using port 10000
PID=$(sudo lsof -t -i:10000)

# Check if a process was found
if [ -z "$PID" ]; then
    echo "No process found running on port 10000"
else
    # Kill the process
    sudo kill $PID
    echo "Process $PID killed"
fi

# Display options to the user
echo
echo "Choose an option to continue:"
echo "1. 7b Model - Load in 4 bit - 7.3 GB VRAM"
echo "2. 7b Model - Load in 8 bit - 10.4 GB VRAM"
echo "3. 7b Model - Load in 16 bit - 16.3 GB VRAM"
echo "4. 13b Model - Load in 4 bit - 11.1 GB VRAM"
echo "5. 13b Model - Load in 8 bit - 17.0 GB VRAM"
echo "6. 13b Model - Load in 16 bit - 29 GB VRAM"
echo "7. 34b Model - Load in 4 bit - 25.7 GB VRAM"
echo "8. 34b Model - Load in 8 bit - 41.7 GB VRAM"
echo "9. 34b Model - Load in 16 bit - 70 GB VRAM"
echo

# Read user option
read -p "Enter option (1-9): " userOption

# Navigate to the LLaVA directory (assuming it's a subdirectory of the current directory)
cd LLaVA

# Activate the python3 virtual environment
source venv/bin/activate

# Set the CUDA_VISIBLE_DEVICES environment variable
export CUDA_VISIBLE_DEVICES=0,1,2,3

# Start the llava.serve.controller
python3 -m llava.serve.controller --host 127.0.0.1 --port 10000 &

# Start the llava.serve.gradio_web_server
python3 -m llava.serve.gradio_web_server --share --controller http://localhost:10000 --model-list-mode reload &


# Execute the command based on the user's selection
case $userOption in
    1) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-7b --load-4bit ;;
    2) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-7b --load-8bit ;;
    3) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-7b ;;
    4) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-13b --load-4bit ;;
    5) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-13b --load-8bit ;;
    6) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.5-13b ;;
    7) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.6-34b --load-4bit ;;
    8) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.6-34b --load-8bit ;;
    9) python3 -m llava.serve.model_worker --host 127.0.0.1 --controller http://localhost:10000 --port 40000 --worker http://localhost:40000 --model-path liuhaotian/llava-v1.6-34b ;;
    *) echo "Invalid option. Exiting." ;;
esac

echo "All started"

# Wait for a key press before exiting
read -p "Press any key to continue . . . " -n1 -s
echo
